#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global parent xmvn
%global subname mojo
Name:           %{parent}-%{subname}
Version:        4.0.0
Release:        150200.3.4.3
Summary:        XMvn MOJO
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://fedora-java.github.io/xmvn/
Source0:        https://github.com/fedora-java/%{parent}/releases/download/%{version}/%{parent}-%{version}.tar.xz
Patch1:         0001-Mimic-maven-javadoc-plugin-for-source-and-release.patch
Patch2:         0002-module-path-not-allowed-with-release-8.patch
Patch3:         0001-Simple-implementation-of-toolchains-https-github.com.patch
Patch4:         0001-Restore-possibility-to-build-with-Java-8.patch
Patch5:         0002-Revert-Update-compiler-source-target-to-JDK-11.patch
Patch6:         0003-Revert-Use-new-Collection-methods-added-in-Java-9.patch
Patch7:         0004-Add-a-jdk9-profile-to-assure-that-we-are-jdk8-compat.patch
Patch8:         0001-Port-to-Maven-3.8.5.patch
BuildRequires:  %{parent}-api = %{version}
BuildRequires:  %{parent}-core = %{version}
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  xmvn
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-util)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-container-default)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.easymock:easymock)
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
BuildArch:      noarch

%description
This package provides XMvn MOJO, which is a Maven plugin that consists
of several MOJOs.  Some goals of these MOJOs are intended to be
attached to default Maven lifecycle when building packages, others can
be called directly from Maven command line.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package provides %{summary}.

%prep
%setup -q -n %{parent}-%{version}

%autopatch -p1

# Resolver IT won't work either - it tries to execute JAR file, which
# relies on Class-Path in manifest, which is forbidden in Fedora...
find -name ResolverIntegrationTest.java -delete

%pom_remove_plugin -r :maven-site-plugin

%{mvn_package} ":xmvn{,-it}" __noinstall

# Upstream code quality checks, not relevant when building RPMs
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :jacoco-maven-plugin
# FIXME pom macros don't seem to support submodules in profile
%pom_remove_plugin :jacoco-maven-plugin xmvn-it

# remove dependency plugin maven-binaries execution
# we provide apache-maven by symlink
%pom_xpath_remove "pom:executions/pom:execution[pom:id[text()='maven-binaries']]"

# Don't put Class-Path attributes in manifests
%pom_remove_plugin :maven-jar-plugin xmvn-tools

# Remove all dependencies with scope test, since a raw xmvn does not hide them
%pom_remove_dep -r :::test:

pushd %{name}
  %{mvn_file} :{*} %{parent}/@1
popd

%build
pushd %{name}
  xmvn \
    --batch-mode --offline \
    -Dmaven.test.skip=true -Dsource=8 \
    package org.apache.maven.plugins:maven-javadoc-plugin:aggregate

%{mvn_artifact} pom.xml target/%{name}-%{version}.jar

popd

%install
pushd %{name}
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}
popd

%files -f %{name}/.mfiles
%license LICENSE NOTICE
%doc AUTHORS README.md

%files javadoc -f %{name}/.mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Mon May 16 2022 fstrba@suse.com
- Added patch:
  * 0001-Port-to-Maven-3.8.5.patch
    + Allow buiding against unpatched maven 3.8.5
* Tue May 10 2022 fstrba@suse.com
- Upgrade to version 4.0.0
  * Changes:
    +  Bump codecov/codecov-action from 2.0.1 to 2.0.2
    +  Bump codecov/codecov-action from 1 to 2.0.1
    +  Bump commons-compress from 1.20 to 1.21 in /xmvn-parent
    +  Change logic for JPMS detection by Javadoc MOJO
    +  Fix Javadoc generation for non-JPMS project with JDK 11
    +  Remove superflous JARs from assembly
    +  Create a backup file when injecting Manifest
    +  Attach site artifacts only in site lifecycle
    +  Rename xmvn-connector-aether to xmvn-connector
    +  Use try-with-resources to avoid resource leaks
    +  Remove unused AtomicFileCounter class
    +  Update Eclipse project settings
    +  Add separate build profile for code quality tools
    +  Remove prerequisites on Maven version
    +  Drop bisect tool
    +  Move release plugins to pluginManagement
    +  Move prerequisites on Maven version to xmvn-mojo
    +  Fix javadoc warning
    +  Bump junit from 4.12 to 4.13.1 in /xmvn-it/src/test/resources/testBisect
    +  Bump slf4jVersion from 1.8.0-beta4 to 2.0.0-alpha2 in /xmvn-parent
    +  Compile everything whith --release 11
    +  Fix assembly building with Maven Checkstyle Plugin 3.1.0+
    +  Update to latest Checkstyle
    +  Format code to conform to Checkstyle 8.44
    +  Untabify Maven build files
    +  Update Maven plugin versions
    +  Drop Ivy
    +  Drop Gradle
    +  Add support for compiler release setting
    +  Fix Javadoc generation for modular projects
    +  Add JPMS check to Javadoc MOJO
    +  Add missing license headers
    +  Disable I/O write test if the build is running as root
    +  Switch to SHA-256 in CacheManager
    +  Update dependency xmlunit.assertj to xmlunit.assertj3
    +  Fixes #56 - Honour source parameter in javadoc mojo
    +  Implement XMvn toolchain manager
    +  Fix requires generation for self-depending packages
    +  Remove redundant parentheses
    +  Remove redudnant use of this
    +  Relay on implicit access modifiers of interfaces
    +  Rely on implicit boxing
    +  Make use of diamond operator
    +  [test] Use use lambda expressions for creation of DeploymentResult
    +  Remove use of deprecated StringUtils methods
    +  [test] Port tests to JUnit 5
    +  Update to latest dependencies
    +  [test] Add missing assertions about XML output
    +  Use new Collection methods added in Java 9
    +  Remove uses of deprecated Class.newInstance() method
    +  Drop artifact resolution from JAVA_HOME
    +  Update to latest Maven plugin versions
    +  Update compiler source/target to JDK 11
    +  Update Eclipse project settings
    +  Make xmvn-subst honor settings for ignoring duplicate metadata
    +  Allow removing plugins during model validation
    +  Prefer namespaced metadata when duplicates are found
- Removed patches:
  * xmvn-gradle_4_4_1.patch
  * 0001-Fix-resolution-of-aliases-registered-by-add_maven_de.patch
    + Patches the inexisting xmvn-connector-gradle module
  * 0001-Prefer-namespaced-metadata-when-duplicates-are-found.patch
  * 0002-Make-xmvn-subst-honor-settings-for-ignoring-duplicat.patch
  * 0003-Fix-requires-generation-for-self-depending-packages.patch
    + Integrated upstream
- Added patches:
  * 0001-Mimic-maven-javadoc-plugin-for-source-and-release.patch
  * 0002-module-path-not-allowed-with-release-8.patch
    + make Xmvn Javadoc Mojo respect release and source arguments
  * 0001-Simple-implementation-of-toolchains-https-github.com.patch
    + consider toolchains if specifies in Xmvn Javadoc Mojo
  * 0001-Restore-possibility-to-build-with-Java-8.patch
  * 0002-Revert-Update-compiler-source-target-to-JDK-11.patch
  * 0003-Revert-Use-new-Collection-methods-added-in-Java-9.patch
  * 0004-Add-a-jdk9-profile-to-assure-that-we-are-jdk8-compat.patch
    + different fixes to be able to build with JDK8
* Thu Nov 21 2019 fstrba@suse.com
- Upgrade to upstream version 3.1.0
- Removed patches:
  * 0001-Fix-installer-plugin-loading.patch
  * 0001-Port-to-Gradle-4.2.patch
  * 0001-Port-to-Gradle-4.3.1.patch
  * 0001-Support-setting-Xdoclint-none-in-m-javadoc-p-3.0.0.patch
  * 0001-Fix-configuration-of-aliased-plugins.patch
  * 0001-Don-t-use-JAXB-for-converting-bytes-to-hex-string.patch
  * 0001-Use-apache-commons-compress-for-manifest-injection-a.patch
  * 0001-port-to-gradle-4.4.1.patch
  * 0001-Replace-JAXB-parser.patch
    + Integrated in this version
* Wed Mar 27 2019 fstrba@suse.com
- Initial packaging of xmvn-mojo 3.0.0
